@@ -4,7 +4,7 @@ Created on 29.08.2022
 @author: wf
 '''
 from tests.basetest import Basetest
-from justpy.download import Download
+from jpcore.download import Download
 import os
 
 class TestDownlad(Basetest):
@@ -21,5 +21,4 @@ class TestDownlad(Basetest):
         os.makedirs(Download.getCachePath(),exist_ok=True)
         filePath=f"{Download.getCachePath()}/{dbname}"
         Download.downloadFile(url, dbname, targetDirectory=Download.getCachePath())
-        self.assertTrue(os.path.isfile(filePath))
-        
+        self.assertTrue(os.path.isfile(filePath)) 
\ No newline at end of file
